==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/include/tag_wma.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mod: nil; c-basic-offset: 4 -*- */
#ifndef GUARD_tag_wma_h
#define GUARD_tag_wma_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// wma decoder came from bmp-wma plugin.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file tag_wma.h
/// @brief Class for process wma tag header file.

#include "tag.h"

#include "../src/libffwma/avcodec.h"
#include "../src/libffwma/avformat.h"

class MainManager;

/// @brief Class for process wma tag.
class WMATag : public Tag, public SmallObject 
{
public:
    WMATag(const std::string& filename, const MainManager* const mainManager);
    virtual ~WMATag();

private:
    const std::string& filename_;

    bool validFile_;

    AVCodec* avCodec_;
    AVCodecContext* avCodecContext_;
    AVFormatContext* avFormatContext_;

    const MainManager* const mainManager_;

    bool Init();

    virtual void ProcessYear();
    virtual void ProcessTrack();
    virtual void ProcessTitle();
    virtual void ProcessAlbum();
    virtual void ProcessGenre();
    virtual void ProcessArtist();
    virtual void ProcessComment();
    virtual void ProcessTotalTime();
};

std::auto_ptr<Tag> CreateWMATag(const std::string& filename, const MainManager* const mainManager);

#endif

==> sagua_0.2.5-1.tar.gz: sagua-0.2.5/include/tag_wma.h <==
#ifndef GUARD_tag_wma_h
#define GUARD_tag_wma_h
/* -*- Mode: C++; tab-width: 4; indent-tabs-mod: nil; c-basic-offset: 4 -*- */
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// wma decoder came from bmp-wma plugin.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file tag_wma.h
/// @brief Class for process wma tag header file.

#include "tag.h"

#include "../src/libffwma/avcodec.h"
#include "../src/libffwma/avformat.h"

/// @brief Class for process wma tag.
class WMATag : public Tag
{
public:
    WMATag(const std::string& filename);

    ~WMATag();

private:
    AVCodec* avCodec_;
    AVCodecContext* avCodecContext_;
    AVFormatContext* avFormatContext_;

    virtual void ProcessYear();
    virtual void ProcessTrack();
    virtual void ProcessAlbum();
    virtual void ProcessGenre();
    virtual void ProcessArtist();
    virtual void ProcessComment();

    void AVCodecSelect();

    void GetTime();
    void GetTitle(const std::string& filename);
};

std::auto_ptr<Tag> CreateWMATag(const std::string& filename);

#endif
